@@ -1,5 +1,5 @@
 from .const import Messagio, TASK_PRIORITY
-from .decorators import messagio_dataclass, listen_to_message
+from .decorators import listen_to_message
 from .autodiscover import autodiscover_listeners
 from .exceptions import MessageProcessingError
 
@@ -9,5 +9,4 @@ __all__ = [
     "MessageProcessingError",
     "TASK_PRIORITY",
     "autodiscover_listeners",
-    "messagio_dataclass",
 ]
